agentle.mcp.sampling.messages.assistant\_message
================================================

.. automodule:: agentle.mcp.sampling.messages.assistant_message

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      AssistantMessage
      BaseModel
      ImageMessageContent
      TextMessageContent
   